Lotus.Web.Queries.ToolbarComponents (Lotus Web v0.14.5)
View SourceEditor toolbar UI components.
Summary
Functions
Generates a generic error message.
Renders a fieldset-based input with legend acting as floating label.
Functions
Generates a generic error message.
Slots
inner_block(required)
Renders a fieldset-based input with legend acting as floating label.
This approach uses semantic HTML with fieldset/legend to create a natural border cutout effect that works with any background color.
Examples
<.input field={@form[:name]} label="Name" />
<.input field={@form[:email]} type="email" label="Email" />Attributes
id(:any) - Defaults tonil.name(:any)label(:string) - Defaults tonil.value(:any)type(:string) - Defaults to"text". Must be one of"checkbox","color","date","datetime-local","email","file","month","number","password","range","search","select","multiselect","tel","text","textarea","time","url", or"week".field(Phoenix.HTML.FormField) - a form field struct retrieved from the form, for example: @form[:email].errors(:list) - Defaults to[].checked(:boolean) - the checked flag for checkbox inputs.prompt(:string) - the prompt for select inputs. Defaults tonil.search_prompt(:string) - the search prompt for multiselect inputs. Defaults tonil.options(:list) - the options to pass to Phoenix.HTML.Form.options_for_select/2.multiple(:boolean) - the multiple flag for select inputs. Defaults tofalse.show_icons(:boolean) - whether to show icons in select options. Defaults tofalse.- Global attributes are accepted. Supports all globals plus:
["accept", "autocomplete", "capture", "cols", "disabled", "form", "list", "max", "maxlength", "min", "minlength", "multiple", "pattern", "placeholder", "readonly", "required", "rows", "size", "step"].